@@ -1,19 +1,19 @@
 package OpenInteract::ErrorObject;
 
-# $Id: ErrorObject.pm,v 1.4 2001/09/06 14:34:54 lachoy Exp $
+# $Id: ErrorObject.pm,v 1.5 2001/10/24 16:36:23 lachoy Exp $
 
 use strict;
 use Data::Dumper   qw( Dumper );
 use SPOPS::Utility;
 use Text::Wrap     ();
 
-$OpenInteract::ErrorObject::VERSION = sprintf("%d.%02d", q$Revision: 1.4 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::ErrorObject::VERSION = sprintf("%d.%02d", q$Revision: 1.5 $ =~ /(\d+)\.(\d+)/);
 
 my @LIST = (); # keeps errors during request
 my $DEFAULT_ACTION = 'n/a';
 my $DEFAULT_TYPE   = 'n/a';
 
-# 
+#
 # Routines to manipulate the list of errors during a request
 #
 
@@ -41,8 +41,8 @@ sub throw {
 }
 
 
-# Called when we do: OpenInteract::ErrorObject->new() 
-# (see SPOPS->new() for more info and how ->initialize() 
+# Called when we do: OpenInteract::ErrorObject->new()
+# (see SPOPS->new() for more info and how ->initialize()
 # is called)
 
 sub initialize {
@@ -65,9 +65,9 @@ sub initialize {
     $p->{extra} ||= $ei->{extra} || {};
     my $extra_info = undef;
     foreach my $key ( keys %{ $p->{extra} } ) {
-        $R->DEBUG && $R->scrib( 1, "Set (tmp_$key) to $p->{extra}->{ $key }" );
-        $self->{ "tmp_$key" } = $p->{extra}->{ $key };
-        $extra_info .= $p->{extra}->{ $key } . "<br>\n";
+        $R->DEBUG && $R->scrib( 1, "Set (tmp_$key) to $p->{extra}{ $key }" );
+        $self->{ "tmp_$key" } = $p->{extra}{ $key };
+        $extra_info .= $p->{extra}{ $key } . "<br>\n";
     }
 
     # If there was nothing passed in except for the code,
@@ -86,7 +86,7 @@ sub initialize {
 
     # Get the action from $R if not already set
 
-    $p->{action} ||= $R->{current_context}->{action} || $DEFAULT_ACTION;
+    $p->{action} ||= $R->{current_context}{action} || $DEFAULT_ACTION;
 
     # Give a default type if not set
 
@@ -112,9 +112,9 @@ sub initialize {
 
     # Set meta information
 
-    $self->{action}    ||= $R->{current_context}->{action};
-    $self->{user_id}     = $R->{auth}->{user}->id       if ( ref $R->{auth}->{user} );
-    $self->{session_id}  = $R->{session}->{_session_id} if ( ref $R->{session}   );
+    $self->{action}    ||= $R->{current_context}{action};
+    $self->{user_id}     = $R->{auth}{user}->id       if ( ref $R->{auth}{user} );
+    $self->{session_id}  = $R->{session}{_session_id} if ( ref $R->{session}   );
     $self->{browser}     = $head_in->{'User-Agent'};
     $self->{error_time}  = SPOPS::Utility->now;
     $self->{url}         = $R->{path}{original};
@@ -166,19 +166,15 @@ sub as_string {
 Messages
 
 ========
-    User
-========
+User
 $user_msg
 
 ========
-  System
-========
+System
 $sys_msg
 
 STRING
-    if ( $opt->{html} ) {
-        $string =~ s/\n/<br>\n/g;
-    }
+    $string =~ s/\n/<br>\n/g if ( $opt->{html} );
     return $string;
 }
 
