@@ -1,13 +1,13 @@
 package OpenInteract::Handler::Box;
 
-# $Id: Box.pm,v 1.12 2001/10/11 03:53:21 lachoy Exp $
+# $Id: Box.pm,v 1.15 2001/11/20 04:03:48 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( :level );
 use Data::Dumper qw ( Dumper );
 
 @OpenInteract::Handler::Box::ISA     = ();
-$OpenInteract::Handler::Box::VERSION = sprintf("%d.%02d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::Box::VERSION = sprintf("%d.%02d", q$Revision: 1.15 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::Box::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::Box::default_method    = '';
@@ -47,6 +47,8 @@ sub process_boxes {
     if ( $custom_box_class ) {
         eval "require $custom_box_class";
         my $custom_box_method = $BOX_CONFIG->{custom_box_method} || DEFAULT_METHOD;
+        $R->DEBUG && $R->scrib( "Calling custom box handler:",
+                                "$custom_box_class\->$custom_box_method" );
         eval { $custom_box_class->$custom_box_method() };
         if ( $@ ) {
             $R->scrib( 0, "Cannot call custom box handler: $custom_box_class. Error: $@" );
@@ -54,10 +56,14 @@ sub process_boxes {
     }
 
     # Next, weed out boxes without at least a name and assign
-    # class/method or template information as needed
-
-    my @good_boxes = ();
+    # class/method or template information as needed. Also be able to
+    # remove a box from the boxes previously marked as good if someone
+    # has asked us NOT to display it. For instance, if an app doesn't
+    # want a login box it can do:
+    #  push @{ $R->{boxes} }, { name => 'login_box', remove => 'yes' };
 
+    my %good_boxes = ();
+    my @to_remove  = ();
 BOX:
     foreach my $box_info ( @{ $R->{boxes} } ) {
 
@@ -69,6 +75,13 @@ BOX:
             $R->DEBUG && $R->scrib( 1, "Found box with old scalar name-only call: $box_info->{name}" );
         }
 
+        # See if this is a 'remove' request
+
+        if ( $box_info->{remove} ) {
+            push @to_remove, $box_info->{name};
+            next BOX;
+        }
+
         unless ( $box_info->{name} ) {
             $R->scrib( 0, "Box put into the holding area without a name! Not processed.\n",
                           "Info:\n", Dumper( $box_info ) );
@@ -113,16 +126,24 @@ BOX:
 
         $box_info->{weight} ||= DEFAULT_BOX_WEIGHT;
         next BOX if ( $box_info->{weight} > MAX_BOX_WEIGHT );
+
         $R->DEBUG && $R->scrib( 1, "Putting box ($box_info->{name}) onto the",
                                    "stack with weight $box_info->{weight}" );
-        push @good_boxes, $box_info;
+        $good_boxes{ $box_info->{name} } = $box_info;
     }
 
-    # Now, sort the boxes by weight then name
+    # Remove the boxes as requested
+
+    foreach my $remove_name ( @to_remove ) {
+        $R->DEBUG && $R->scrib( 1, "Trying to remove box: $remove_name" );
+        delete $good_boxes{ $remove_name } if ( $remove_name );
+    }
+
+    # Sort the boxes by weight then name
 
     my @sorted_boxes = sort { $a->{weight} <=> $b->{weight} ||
                               $a->{name} cmp $b->{name} }
-                       @good_boxes;
+                       values %good_boxes;
 
     # Grab the template that we'll plug the box content into
 
@@ -136,13 +157,13 @@ BOX:
         $box_template_name    = $2;
     }
     $box_template_package  ||= 'base_box';
-    $box_template_fullname ||= "$box_template_name\:\:$box_template_package";
+    $box_template_fullname ||= "$box_template_package\:\:$box_template_name";
 
     $R->DEBUG && $R->scrib( 2, "Using box shell template $box_template_fullname" );
 
     # Generate content for each box
 
-    my @boxes = ();
+    my @content = ();
     $R->DEBUG && $R->scrib( 2, "Sorted boxes currently in the list:\n", Dumper( \@sorted_boxes ) );
     foreach my $box_info ( @sorted_boxes ) {
         my $shell_params = {};
@@ -176,13 +197,13 @@ BOX:
             $box_content = $R->template->handler( {}, $shell_params,
                                                   { name => $box_template_fullname } );
         }
-        push @boxes, $box_content;
+        push @content, $box_content;
     }
 
     my $sep_string = $R->{theme}->property_value( 'box_separator' )
                      || $BOX_CONFIG->{default_separator}
                      || DEFAULT_SEPARATOR;
-    return join( $sep_string, @boxes );
+    return join( $sep_string, @content );
 }
 
 1;
@@ -215,6 +236,10 @@ OpenInteract::Handler::Box -- Handle input and output for independent "boxes"
              params => { zip_code => $zip };
  push @{ $R->{boxes} }, $box;
 
+ # Remove a box added in another part of the system
+
+ push @{ $R->{boxes} }, { name => 'motd', remove => 'yes' };
+
 =head1 DESCRIPTION
 
 =head1 CONFIGURATION
@@ -335,6 +360,21 @@ Just used to identify the box.
 
 =item *
 
+B<remove> ($) (optional)
+
+If you use this parameter you are telling the box handler to remove a
+box with name 'name'. This box does not have to be added by you or in
+your package -- for instance, you might want to always get rid of the
+'user_info' and 'login' boxes that come with OI:
+
+ push @{ $R->{boxes} }, { name => 'user_info_box', remove => 'yes' },
+                        { name => 'login_box', remove => 'yes' };
+
+This does require you to know the name, but that should not be too
+onerous a burden.
+
+=item *
+
 B<title> ($) (optional)
 
 Display name of box used in the 'shell' wrapper, if you elect to use
