@@ -1,6 +1,6 @@
 package OpenInteract::Handler::Security;
 
-# $Id: Security.pm,v 1.11 2001/09/28 18:59:52 lachoy Exp $
+# $Id: Security.pm,v 1.12 2001/11/20 04:05:40 lachoy Exp $
 
 use strict;
 use Data::Dumper             qw( Dumper );
@@ -9,7 +9,7 @@ use SPOPS::Secure::Hierarchy qw( $ROOT_OBJECT_NAME );
 use OpenInteract::Handler::GenericDispatcher qw( DEFAULT_SECURITY_KEY );
 
 @OpenInteract::Handler::Security::ISA     = qw( OpenInteract::Handler::GenericDispatcher SPOPS::Secure );
-$OpenInteract::Handler::Security::VERSION = sprintf("%d.%02d", q$Revision: 1.11 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::Security::VERSION = sprintf("%d.%02d", q$Revision: 1.12 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::Security::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::Security::default_method    = 'listing';
@@ -17,7 +17,6 @@ $OpenInteract::Handler::Security::default_method    = 'listing';
 %OpenInteract::Handler::Security::security          = ( DEFAULT_SECURITY_KEY() => SEC_LEVEL_WRITE );
 
 use constant MAIN_SCRIPT => '/Security';
-use constant OI_PACKAGE  => 'base_security';
 
 my $SECURE_CLASS = 'SPOPS::Secure';
 
@@ -57,10 +56,10 @@ sub listing {
                               hierarchy_secure => $action_class->isa( 'SPOPS::Secure::Hierarchy' ) };
         $classes_visited{ $action_class }++;
     }
+    $R->{page}{title} = 'Security Listing';
     return $R->template->handler( {}, { object_list => \@object_class,
                                         action_list => \@action_class },
-                                  { db      => 'object_class_list',
-                                    package => OI_PACKAGE } );
+                                  { name => 'base_security::object_class_list' });
 }
 
 
@@ -130,8 +129,7 @@ sub show {
     $params->{scope_list} = \@scopes;
     $R->{page}->{title} = 'Edit Object Security';
     return $R->template->handler( {}, $params,
-                                  { db      => 'assign_object_security',
-                                    package => 'base_security' } );
+                                  { name => 'base_security::assign_object_security' } );
 }
 
 
@@ -172,8 +170,7 @@ sub hierarchy_show {
                    object_url         => $url };
     $R->{page}->{title} = 'Object Hierarchy Security';
     return $R->template->handler( {}, $params,
-                                { db      => 'hierarchy_security',
-                                  package => 'base_security' } );
+                                { name => 'base_security::hierarchy_security' } );
 }
 
 
@@ -207,6 +204,7 @@ sub edit {
     # set its security for the given object class and ID
 
     my ( $total, $success ) = ( 0, 0 );
+    my ( @status_ok );
     my $security_object_class = $R->security_object;
     foreach my $info ( @scope ) {
         $total++;
@@ -218,29 +216,36 @@ sub edit {
                                 scope          => $info->[0],
                                 scope_id       => $info->[1],
                                 security_level => $level };
-        my $method = ( $level eq 'clear' ) 
+        my $method = ( $level eq 'clear' )
                        ? 'remove_item_security' : 'set_item_security';
-        $success += eval { $SECURE_CLASS->$method( $security_params ) };
+        eval { $SECURE_CLASS->$method( $security_params ) };
         if ( $@ ) {
             my $ei = OpenInteract::Error->set( SPOPS::Error->get );
             $R->scrib( 0, "Error trying to set security!\n$@\n", Dumper( $ei ) );
             $R->throw({ code => 406 });
         }
+        else {
+            push @status_ok, $object_id;
+        }
     }
     my ( $error_msg );
-    if ( $total != $success ) {
+    if ( $total != scalar @status_ok ) {
         $error_msg = "Attempted to set ($total); set ($success). Some " .
                      "attempts had errors.";
     }
+    my $status_msg = "Security for $object_class set for the following IDs: " .
+                     join( ', ', @status_ok );
 
     my $return_url = $apr->param( 'return_url' );
     if ( $return_url ) {
         my ( $action_class, $action_method ) = $R->lookup_action( 'redirect' );
-        return $action_class->$action_method({ url       => $return_url,
-                                               error_msg => $error_msg });
+        return $action_class->$action_method({ url        => $return_url,
+                                               error_msg  => $error_msg,
+                                               status_msg => $status_msg });
     }
     return $class->show({ object_class => $object_class,
                           object_id    => $object_id,
+                          status_msg   => $status_msg,
                           error_msg    => $error_msg });
 }
 
@@ -322,7 +327,9 @@ sub _find_object_info {
     else {
         my $apr = OpenInteract::Request->instance->apache;
         $object_class = $p->{object_class} ||
-                        $apr->param( 'object_class' );
+                        $apr->param( 'object_class' ) ||
+                        $p->{handler_class} ||
+                        $apr->param( 'handler_class' );
         $object_id    = $p->{object_id} ||
                         $apr->param( 'oid' ) ||
                         $apr->param( 'object_id' ) ||
