@@ -1,12 +1,12 @@
 package OpenInteract::Handler::SystemBoxes;
 
-# $Id: SystemBoxes.pm,v 1.8 2001/08/12 15:40:32 lachoy Exp $
+# $Id: SystemBoxes.pm,v 1.9 2001/09/22 16:32:07 lachoy Exp $
 
 use strict;
 use SPOPS::Secure qw( :level );
 
 @OpenInteract::Handler::SystemBoxes::ISA     = qw();
-$OpenInteract::Handler::SystemBoxes::VERSION = sprintf("%d.%02d", q$Revision: 1.8 $ =~ /(\d+)\.(\d+)/);
+$OpenInteract::Handler::SystemBoxes::VERSION = sprintf("%d.%02d", q$Revision: 1.9 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::SystemBoxes::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::SystemBoxes::default_method    = 'handler';
@@ -56,27 +56,27 @@ sub handler {
     # First deal with the user info box, and any other boxes that
     # depend on the user being logged in
 
-    if ( $R->{auth}->{logged_in} ) {
+    if ( $R->{auth}{logged_in} ) {
         $R->DEBUG && $R->scrib( 1, "Generating box information for user info box" );
-        push @{ $R->{boxes} }, $class->_assign_params({ 
+        push @{ $R->{boxes} }, $class->_assign_params({
                                            action   => 'user_info_box',
                                            defaults => \%USER_BOX_DEFAULTS,
-                                           params   => { user => $R->{auth}->{user} } });
+                                           params   => { user => $R->{auth}{user} } });
 
         # Now, if the user is a member of the site admin group, add the
         # 'Admin Tools' box and the 'Templates Used' box.
 
         my $site_admin_id = $conf->{default_objects}{site_admin_group};
         my $supergroup_id = $conf->{default_objects}{supergroup};
-        foreach my $group ( @{ $R->{auth}->{group} } ) {
+        foreach my $group ( @{ $R->{auth}{group} } ) {
             next unless ( $group->{group_id} =~ /^($site_admin_id|$supergroup_id)$/ );
             $R->DEBUG && $R->scrib( 1, "User is in site admin group:  generating info for ",
                                        "admin_tools_box and templates used box" );
             push @{ $R->{boxes} }, $class->_assign_params({
-                                             action => 'admin_tools_box',
+                                             action   => 'admin_tools_box',
                                              defaults => \%ADMIN_BOX_DEFAULTS });
             push @{ $R->{boxes} }, $class->_assign_params({
-                                             action => 'templates_used_box', 
+                                             action   => 'templates_used_box',
                                              defaults => \%TEMPLATES_USED_BOX_DEFAULTS });
             last;
         }
@@ -97,12 +97,12 @@ sub handler {
 sub _assign_params {
     my ( $class, $p ) = @_;
     my $R = OpenInteract::Request->instance;
-    my $action = $R->lookup_action( $p->{action}, { return       => 'info', 
+    my $action = $R->lookup_action( $p->{action}, { return       => 'info',
                                                     skip_default => 1 } );
     $action ||= {};
     my %params = ();
     foreach my $key ( @BOX_KEYS ) {
-        $params{ $key } = $action->{ $key } || $p->{defaults}->{ $key };
+        $params{ $key } = $action->{ $key } || $p->{defaults}{ $key };
     }
     $params{params} = $p->{params};
     return \%params;
@@ -128,16 +128,15 @@ sub templates_used {
             ( $package, $name ) = $R->site_template->parse_name( $template );
             $full_name = $template;
         }
-        next if ( $tmpl_used{ $package }->{ $name } );
-        $tmpl_used{ $package }->{ $name }++;
-        push @{ $tmpl_by_package{ $package } }, 
-                            { name      => $name, 
+        next if ( $tmpl_used{ $package }{ $name } );
+        $tmpl_used{ $package }{ $name }++;
+        push @{ $tmpl_by_package{ $package } },
+                            { name      => $name,
                               id        => $template_id,
                               full_name => $full_name };
     }
     return $R->template->handler( {}, { templates_used => \%tmpl_by_package },
-                                  { db      => 'templates_used_box', 
-                                    package => 'base_box' } );
+                                  { name => 'base_box::templates_used_box' } );
 }
 
 1;
@@ -166,7 +165,7 @@ OpenInteract::Handler::SystemBoxes -- Generate default boxes that appear on all
  # In the main box handler (normally 'OpenInteract::Handler::Box' 
  # or '<MyWebsite>::Handler::Box')
 
- my $system_box_class = $R->CONFIG->{box}->{system_box_handler};
+ my $system_box_class = $R->CONFIG->{box}{system_box_handler};
  $system_box_class->handler();
 
 =head1 DESCRIPTION
