@@ -1,51 +1,52 @@
 package OpenInteract::Handler::User;
 
-# $Id: User.pm,v 1.6 2001/09/14 12:22:34 lachoy Exp $
+# $Id: User.pm,v 1.7 2001/10/31 13:58:24 lachoy Exp $
 
 use strict;
 use Data::Dumper  qw( Dumper );
 use OpenInteract::Handler::GenericDispatcher qw( DEFAULT_SECURITY_KEY );
 use SPOPS::Secure qw( :level :scope );
 
-@OpenInteract::Handler::User::ISA     = qw( OpenInteract::Handler::GenericDispatcher  SPOPS::Secure );
-$OpenInteract::Handler::User::VERSION = sprintf("%d.%02d", q$Revision: 1.6 $ =~ /(\d+)\.(\d+)/);
+@OpenInteract::Handler::User::ISA     = qw( OpenInteract::Handler::GenericDispatcher );
+$OpenInteract::Handler::User::VERSION = sprintf("%d.%02d", q$Revision: 1.7 $ =~ /(\d+)\.(\d+)/);
 
 $OpenInteract::Handler::User::author            = 'chris@cwinters.com';
 $OpenInteract::Handler::User::default_method    = 'search_form';
-@OpenInteract::Handler::User::forbidden_methods = qw(
-      _search_params _search_params_ldap _search_params_dbi );
-%OpenInteract::Handler::User::security          = (
-      DEFAULT_SECURITY_KEY() => SEC_LEVEL_READ,
-      edit   => SEC_LEVEL_WRITE,
-      remove => SEC_LEVEL_WRITE );
+@OpenInteract::Handler::User::forbidden_methods = ();
+%OpenInteract::Handler::User::security          = ();
 
 use constant MAIN_SCRIPT => '/User';
 
-
 sub search_form {
-    return OpenInteract::Request->instance->template->handler(
-                   {}, {}, { name => 'base_user::user_search_form' } );
+    my ( $class, $p ) = @_;
+    my $R = OpenInteract::Request->instance;
+    $R->{page}{title} = 'Search for User Records';
+    return $R->template->handler( {}, $p,
+                                  { name => 'base_user::user_search_form' } );
 }
 
 
-sub listing {
+sub search {
     my ( $class, $p ) = @_;
     my $R = OpenInteract::Request->instance;
     my $params = { main_script => MAIN_SCRIPT,
+                   status_msg  => $p->{status_msg},
                    error_msg   => $p->{error_msg} };
     my $fetch_params = $class->_search_params;
-    $R->DEBUG && $R->scrib( 1, "Searching for users with parameters\n",
+    $R->DEBUG && $R->scrib( 2, "Searching for users with parameters\n",
                                Dumper( $fetch_params ) );
     $params->{user_iterator} = eval { $R->user->fetch_iterator( $fetch_params) };
     if ( $@ ) {
         OpenInteract::Error->set( SPOPS::Error->get );
         $R->throw({ code => 404 });
+        $params->{error_msg} .= "<br>Error running search: $@";
     }
     $R->{page}{title} = 'User Listing';
     return $R->template->handler( {}, $params,
-                                  { name => 'base_user::user_list' } );
+                                  { name => 'base_user::user_search_results' } );
 }
 
+
 sub _search_params {
     my ( $class ) = @_;
     my $R   = OpenInteract::Request->instance;
@@ -99,45 +100,43 @@ sub show {
     # theme_list => eval { $R->theme->fetch_group( { order => 'title' } ) },
 
     my $params = { main_script => MAIN_SCRIPT,
-                   error_msg   => $p->{error_msg} };
+                   error_msg   => $p->{error_msg},
+                   status_msg  => $p->{status_msg} };
     $params->{user} = $p->{user};
     unless ( $params->{user} ) {
         my $user_id = $R->apache->param( 'user_id' ) || $R->apache->param( 'uid' );
-        $params->{user}  = eval { $R->user->fetch( $user_id ) };
-        if ( $@ ) {
-            OpenInteract::Error->set( SPOPS::Error->get );
-            $R->throw({ code => 404 });
-            $R->scrib( 0, "Cannot retrieve user ($user_id) ($@) $SPOPS::Error::system_msg" );
+        if ( $user_id ) {
+            $params->{user}  = eval { $R->user->fetch( $user_id ) };
+            if ( $@ ) {
+                OpenInteract::Error->set( SPOPS::Error->get );
+                $R->throw({ code => 404 });
+                $R->scrib( 0, "Cannot retrieve user ($user_id) ($@) $SPOPS::Error::system_msg" );
+                return $class->search_form({ error_msg => "Could not retrieve requested record ($@)" });
+            }
         }
     }
 
     # If the user has only READ access to module and there is no UID
     # or user object, there's no reason to continue
 
-    if ( ! $params->{user} and $p->{level} < SEC_LEVEL_WRITE ) {
+    unless ( $params->{user} or $R->{auth}{is_admin} ) {
         my $msg = 'Sorry, you do not have access to create a new user object. Returning to listing.';
         $R->scrib( 0, "No permission to create new user." );
-        return $class->listing({ error_msg => $msg });
+        return $class->search_form({ error_msg => $msg });
     }
 
     my $obj_level = ( $params->{user} )
-                      ? $params->{user}{tmp_security_level}
-                      : SEC_LEVEL_WRITE;
+                      ? $params->{user}{tmp_security_level} : SEC_LEVEL_WRITE;
 
     $params->{user} ||= $R->user->new({ theme_id => $R->{theme}{theme_id} });
-    $R->DEBUG && $R->scrib( 1, "Levels  $params->{user}{user_id}: $obj_level/$p->{level}" );
+    $R->DEBUG && $R->scrib( 1, "Security  $params->{user}{user_id}: ($obj_level)" );
     $params->{group_list} = eval { $params->{user}->group };
 
-    my $tmpl_name = 'user_detail';
-
-    if ( $p->{level} == SEC_LEVEL_WRITE and $obj_level == SEC_LEVEL_WRITE ) {
-        $tmpl_name = 'user_form';
-    }
-
+    my $tmpl_name = ( $obj_level == SEC_LEVEL_WRITE )
+                      ? 'user_form' : 'user_detail';
     $R->{page}{title} = 'View User Detail';
     return $R->template->handler( {}, $params,
-                                  { package => 'base_user',
-                                    db      => $tmpl_name  } );
+                                  { name => "base_user::$tmpl_name"  } );
 }
 
 
@@ -161,7 +160,7 @@ sub edit {
     my $obj_level = ( $user ) ? $user->{tmp_security_level} : SEC_LEVEL_WRITE;
     if ( $obj_level < SEC_LEVEL_WRITE ) {
         my $user_msg = 'Sorry, you do not have access to modify this user object. Returning to listing.';
-        return $class->listing({ error_msg => $user_msg });
+        return $class->search_form({ error_msg => $user_msg });
     }
 
     # Note if this user is new so we can do some security fun after
@@ -172,6 +171,8 @@ sub edit {
         $is_new++;
     }
 
+    my ( @status );
+
     # Uncomment the code if you are allowing users to change their own themes
     # Track this so we can change the theme if the user changed it.
 
@@ -183,9 +184,15 @@ sub edit {
     }
     my $password = $apr->param( 'password' );
     if ( $password ) {
+        my $password_confirm = $apr->param( 'password_conf' );
+        unless ( $password eq $password_confirm ) {
+            return $class->show({ user      => $user,
+                                  error_msg => 'Passwords do not match. Please re-enter.' });
+        }
         $R->DEBUG && $R->scrib( 1, "User asked to change password. Changing." );
         $password = $R->user->crypt_it( $password ) if ( $R->CONFIG->{login}{crypt_password} );
         $user->{password} = $password;
+        push @status, "Password changed";
     }
 
     eval { $user->save };
@@ -195,7 +202,7 @@ sub edit {
         $R->throw({ code => 407 });
         $R->scrib( 0, "Cannot save user object: $SPOPS::Error::system_msg" );
         return $class->show({ user      => $user,
-                              error_msg => 'Cannot save user object! See error log for details...' });
+                              error_msg => "Error saving user record ($@)" });
     }
 
     # If this is a new user, allow the user to edit his/her own record;
@@ -211,6 +218,13 @@ sub edit {
                                   scope_id => $user->id });
             $user->make_public();
         };
+        if ( $@ ) {
+            $R->scrib( 0, "Error modifying group membership: $@" );
+            my $error_msg = "Record created but group membership inconsistent.";
+            return $class->show({ user      => $user,
+                                  error_msg => $error_msg });
+        }
+        push @status, "User record made part of 'public' group";
     }
 
 
@@ -222,9 +236,11 @@ sub edit {
 #   $R->{theme} = eval { $R->theme->fetch( $user->{theme_id} ) };
 # }
 
-    $p->{user}       = $user;
-    $p->{status_msg} = 'User information updated.';
-    return $class->show( $p );
+
+    my $action = ( $is_new ) ? 'created' : 'updated';
+    unshift @status, "User record successfully $action";
+    return $class->show({ user       => $user,
+                          status_msg => join( "<br>\n", @status ) });
 }
 
 
@@ -234,11 +250,11 @@ sub remove {
     if ( my $user_id = $R->apache->param( 'user_id' ) ) {
         my $user = eval { $R->user->fetch( $user_id ) };
         if ( $@ or ! $user ) {
-            return $class->listing({ error_msg => 'Cannot remove user -- object not created properly.' });
+            return $class->search_form({ error_msg => 'Cannot remove user -- object not created properly.' });
         }
         if ( $user->{tmp_security_level} < SEC_LEVEL_WRITE ) {
             my $user_msg = 'Sorry, you do not have access to remove this user object. Returning to listing.';
-            return $class->listing({ error_msg => $user_msg });
+            return $class->search_form({ error_msg => $user_msg });
         }
 
         eval { $user->remove };
@@ -246,41 +262,11 @@ sub remove {
             OpenInteract::Error->set( SPOPS::Error->get );
             $R->throw({ code => 405 });
             $R->scrib( 0, "Failed to remove user object: ($@) $SPOPS::Error::system_msg" );
-            $p->{error_msg} = 'Cannot remove user object! See error log for details...';
+            my $error_msg = "Error removing user object. ($@)";
+            return $class->search_form({ error_msg => $error_msg });
         }
     }
-    return $class->listing( $p );
+    return $class->search_form({ status_msg => 'User record successfully removed' });
 }
 
 1;
-
-__END__
-
-=pod
-
-=head1 NAME
-
-OpenInteract::Handler::User - Functions to manipulate user records
-
-=head1 SYNOPSIS
-
-=head1 DESCRIPTION
-
-=head1 METHODS
-
-=head1 TO DO
-
-=head1 BUGS
-
-=head1 COPYRIGHT
-
-Copyright (c) 2001 intes.net, inc.. All rights reserved.
-
-This library is free software; you can redistribute it and/or modify
-it under the same terms as Perl itself.
-
-=head1 AUTHORS
-
-Chris Winters <chris@cwinters.com>
-
-=cut
