@@ -1,6 +1,6 @@
 package OpenInteract::SQLInstall::StaticPage;
 
-# $Id: StaticPage.pm,v 1.1.1.1 2001/02/02 06:20:37 lachoy Exp $
+# $Id: StaticPage.pm,v 1.2 2001/07/10 13:56:03 lachoy Exp $
 
 # Do installation of SQL for this package
 
@@ -10,7 +10,7 @@ use vars qw( %HANDLERS );
 @OpenInteract::SQLInstall::StaticPage::ISA = qw( OpenInteract::SQLInstall );
 
 my %files = (
-  tables   => [ 'basic_page.sql' ],
+  tables   => [ 'basic_page.sql' ], # 'basic_page_content.sql' ],
   security => [ 'install_security.dat' ],
 );
 
